FspServiceStop

Function FspServiceStop 

pub unsafe extern "C" fn FspServiceStop(Service: *mut FSP_SERVICE)
Stops a running service.

Stopping a service usually happens when the Service Control Manager instructs the service to stop. In some situations (e.g. fatal errors) the service may wish to stop itself. It can do so in a clean manner by calling this function.

@param Service The service object. @return STATUS_SUCCESS or error code.